Module threading

Module threading 

Structs

BlockEventId
BlockEventIdArgs
BlockEventIdBuilder
ThreadEdge
ThreadEdgeArgs
ThreadEdgeBuilder
ThreadPointer
ThreadPointerArgs
ThreadPointerBuilder
ThreadPointerKind
ThreadingSnapshot
ThreadingSnapshotArgs
ThreadingSnapshotBuilder
TimelineBlockEntry
TimelineBlockEntryArgs
TimelineBlockEntryBuilder
TimelineBlockKind

Enums

BlockEventIdOffset
ThreadEdgeOffset
ThreadPointerOffset
ThreadingSnapshotOffset
TimelineBlockEntryOffset

Constants

ENUM_MAX_THREAD_POINTER_KINDDeprecated
ENUM_MAX_TIMELINE_BLOCK_KINDDeprecated
ENUM_MIN_THREAD_POINTER_KINDDeprecated
ENUM_MIN_TIMELINE_BLOCK_KINDDeprecated
ENUM_VALUES_THREAD_POINTER_KINDDeprecated
ENUM_VALUES_TIMELINE_BLOCK_KINDDeprecated
THREADING_SNAPSHOT_IDENTIFIER

Functions

finish_size_prefixed_threading_snapshot_buffer
finish_threading_snapshot_buffer
root_as_threading_snapshot
Verifies that a buffer of bytes contains a ThreadingSnapshot and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_threading_snapshot_unchecked.
root_as_threading_snapshot_unchecked
Assumes, without verification, that a buffer of bytes contains a ThreadingSnapshot and returns it.
root_as_threading_snapshot_with_opts
Verifies, with the given options, that a buffer of bytes contains a ThreadingSnapshot and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_threading_snapshot_unchecked.
size_prefixed_root_as_threading_snapshot
Verifies that a buffer of bytes contains a size prefixed ThreadingSnapshot and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use size_prefixed_root_as_threading_snapshot_unchecked.
size_prefixed_root_as_threading_snapshot_unchecked
Assumes, without verification, that a buffer of bytes contains a size prefixed ThreadingSnapshot and returns it.
size_prefixed_root_as_threading_snapshot_with_opts
Verifies, with the given verifier options, that a buffer of bytes contains a size prefixed ThreadingSnapshot and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_threading_snapshot_unchecked.
threading_snapshot_buffer_has_identifier
threading_snapshot_size_prefixed_buffer_has_identifier