root_as_threading_snapshot

Function root_as_threading_snapshot 

pub fn root_as_threading_snapshot(
    buf: &[u8],
) -> Result<ThreadingSnapshot<'_>, InvalidFlatbuffer>
Verifies that a buffer of bytes contains a ThreadingSnapshot and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_threading_snapshot_unchecked.