root_as_threading_snapshot_unchecked

Function root_as_threading_snapshot_unchecked 

pub unsafe fn root_as_threading_snapshot_unchecked(
    buf: &[u8],
) -> ThreadingSnapshot<'_>
Assumes, without verification, that a buffer of bytes contains a ThreadingSnapshot and returns it.

Safety

Callers must trust the given bytes do indeed contain a valid ThreadingSnapshot.